# coding: utf-8

"""
    ARLAS permissions API

    permissions REST services

    OpenAPI spec version: 15.0.0-beta.0
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .error import Error
from .resource import Resource
